=====
XtendCMS
=====

XtendCMS is a admin styling app for the wagtail cms system.

Quick start
-----------

1. Add "xtendcms" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'xtendcms',
    ]

2. Run ``python manage.py migrate`` to create the XtendCMS models.

